==> sbSortedLogistics_1.0.11.zip: sbSortedLogistics_1.0.11/readme.md <==
# Usage #

by default this mod always shows the sorting gui but does no automatic sorting.  
automatic sorting can be paused via hotkey, shortcut or settings option.  
display conditions for the sorting gui and finely grained automatic sorting can be configured in the mod settings.  
the sorting gui shows sort buttons for manual sorting and checkboxes with the state of automatic sorting where applicable and configured.

while the sorting of entities is feature complete, books and planners have sever limitations:

- books and planners in 'My library' can not be sorted at all.
- the sorting gui can only be attached to books and planners inside an inventory.
- books and planners in the 'Game library' can only be automatically sorted and only when picked up.
- books in the 'Game library' can not sort their entries.

if you want better support for books and planners you can request that here: [blueprint library needs some love](https://forums.factorio.com/127764)


---
# Features #

## Settings ##

- when and how much the sorting gui should display can be configured.
- sorting can also be triggered by configurable hotkeys.
- automatic sorting can be configured finely grained.
- automatic sorting can be paused.

## Entities ##

- the sorting gui is attached to entities where applicable.
- primary, secondary and most other inventories of entities can be sorted.
- filter slots inside logistic sections can be sorted. this means also signals in case of the constant combinator.
- infinity filters can be sorted.
- automatic sorting when opening and closing an entity can be configured.

## Items ##

- the sorting gui is attached to books and planners where applicable.
- entity and tile filters of deconstruction planners can be sorted eliminating doubles.
- upgrade mappings of upgrade planners can be sorted eliminating doubles.
- entries in books can be sorted.
- books and planners inside books can be sorted recursively.
- automatic sorting when opening, closing and picking up an item can be configured.

## Multiplayer ##

- the mod _should_ be usable in multiplayer. i did only basic tests, reports in that regard are highly appreciated.

## To Do ##

- markets: have not found a mod to test that with
- equipment: not sure if building an auto tetris algorithm is that usefull


---
# Known limitations #

- books and planners inside 'My library' can not be sorted at all.
- books and planners inside 'Game library' can not have the sorting gui attached.
- books and planners inside 'Game library' can not be automatically sorted when opened or closed.
- books inside 'Game library' can not sort their entries.

==> sbSortedLogistics_1.0.12.zip: sbSortedLogistics_1.0.12/readme.md <==
# Usage #

by default this mod always shows the sorting gui but does no automatic sorting.  
display conditions for the sorting gui and finely grained automatic sorting can be configured in the mod settings.  
the sorting gui shows sort buttons for manual sorting and checkboxes with the state of automatic sorting where applicable and configured.

while the sorting of entities is feature complete, books and planners have sever limitations:

- books and planners inside an inventory work properly.
- books and planners in the 'Game library' are only detected when held in the cursor.
- books in the 'Game library' can not sort their entries.
- books and planners in 'My library' can not be changed at all.

if you want better support for books and planners you can request that here: [blueprint library needs some love](https://forums.factorio.com/127764)


---
# Features #

## Settings ##

- when and how much the sorting gui should display can be configured.
- sorting can also be triggered by configurable hotkeys.
- automatic sorting can be configured finely grained.
- automatic sorting can be paused via hotkey, shortcut or settings option.

## Entities ##

- the sorting gui is attached to entities where applicable.
- primary, secondary and most other inventories of entities can be sorted.
- filter slots inside logistic sections can be sorted. this means also signals in case of the constant combinator.
- infinity filters can be sorted.
- automatic sorting when opening and closing an entity can be configured.

## Items ##

- the sorting gui is attached to books and planners where applicable.
- entity and tile filters of deconstruction planners can be sorted eliminating doubles.
- upgrade mappings of upgrade planners can be sorted eliminating doubles.
- entries in books can be sorted.
- books and planners inside books can be sorted recursively.
- automatic sorting when opening, closing and picking up an item can be configured.

## Multiplayer ##

- the mod _should_ be usable in multiplayer. i did only basic tests, reports in that regard are highly appreciated.

## To Do ##

- markets: have not found a mod to test that with
- equipment: not sure if building an auto tetris algorithm is that usefull


---
# Known issues #

- the autosort shortcut button does not properly sync with the user setting when loading an older savegame. this is a visual glitch.
- resolution or scaling changes can push the gui outside the screen. enter the "`/sortme reset`" command.


---
# Known limitations #

- books and planners inside 'My library' can not be sorted at all.
- books and planners inside 'Game library' can not have the sorting gui attached.
- books and planners inside 'Game library' can not be automatically sorted when opened or closed.
- books inside 'Game library' can not sort their entries.
